@@ -1,4 +1,4 @@
-__version__ = "0.2.6"
+__version__ = "0.3.0"
 import os
 import argparse
 from rich.console import Console
@@ -458,13 +458,13 @@ def main():
     else:
         rich_table(allpathtitle, allpathscolumns, allpathsRows, emptyattributes)
     # ================================================================================================
-    newlyad_title = f"All Newly added Paths for considerations in {company}"
+    newlyad_title = f"Differentiated paths that contains {company}"
 
     newlyad_columns = [
         "no.",
-        f"{supplier} replaced paths",
-        f"New {company} repo paths",
-        f"{company} or other vendors paths",
+        f"paths",
+        f"paths",
+        f"paths",
     ]
 
     newlyad_Rows = [(actualreplacedPaths, conewprojectsPaths, nonconewprojectsPaths)]
